#!/bin/sh

# The input arguments to this script are set up in 
# Xyce_Test/TestScripts/tsc_run_test_suite and are as follows:
# $1 = location of Xyce binary
# $2 = location of xyce_verify.pl script
# $3 = location of compare script 
# $4 = location of circuit file to test
# $5 = location of gold standard prn file

# If Xyce does not produce a prn file, then we return exit code 10
# Otherwise we return the exit code of compare or xyce_verify.pl

XYCE=$1
CIRFILE=$4
GOLDPRN=$5

GOLDERRORS=`echo "$GOLDPRN" | sed 's/\.prn/.err/g'`
if [ ! -f $GOLDERRORS ];         then echo "Exit code = 1"
 exit 1 ; fi
rm -f errors output gold_errors
$XYCE $CIRFILE > output 2>&1 

tr -d \\000 < output | grep "Voltage Node" | sort | uniq > errors
grep "Voltage Node" $GOLDERRORS | sort | uniq > gold_errors

rm output

perl -i -pe 's/\r//g' errors
diff -q errors gold_errors > $CIRFILE.prn.out 2> $CIRFILE.prn.err
if [ "$?" -ne "0" ]; then
  echo "Exit code = 2"
  exit 2
fi
echo "Exit code = 0"
exit 0
