#!/bin/sh

# The input arguments to this script are set up in 
# Xyce_Test/TestScripts/tsc_run_test_suite and are as follows:
# $1 = location of Xyce binary
# $2 = location of xyce_verify.pl script
# $3 = location of compare script 
# $4 = location of circuit file to test
# $5 = location of gold standard prn file

# If Xyce does not produce a prn file, then we return exit code 10.
# If Xyce succeeds, but the test fails, then we return exit code 2.
# If the shell script fails for some reason, then we return exit code 1.
# Otherwise we return the exit code of compare or xyce_verify.pl

# Since the shell script runs Xyce also, it is responsible for capturing any
# error output from Xyce.  The script run_xyce_regression captures the test
# output and handles the resulting files.  

XYCE=$1
XYCE_VERIFY=$2

CIR1=homotopy-tecplot.cir
CIR2=homotopy-prn.cir

$XYCE $CIR1 > $CIR1.out 2> $CIR1.err
if [ "$?" -ne "0" ]; then
  echo "Exit code = 10"
  exit 10
fi

$XYCE $CIR2 > $CIR2.out 2> $CIR2.err
if [ "$?" -ne "0" ]; then
  echo "Exit code = 10"
  exit 10
fi

# test that the prn output and the tecplot output are identical except for the headers:
grep -v "Index" $CIR1.HOMOTOPY.dat | grep -v "End" | grep -v "TIME" | grep -v "I(VB)" | grep -v "I(VIC)" | grep -v "ZONE" | grep -v "TITLE" | grep -v "VARIABLES" > $CIR1.prn2
grep -v "GSTEP" $CIR2.HOMOTOPY.prn | grep -v "End" > $CIR2.prn2
#grep -v "GSTEP" $CIR2.HOMOTOPY.prn > $CIR2.prn2
#grep -v "End" $CIR2.HOMOTOPY.prn > $CIR2.prn2

TEST0=$(diff -w $CIR1.prn2 $CIR2.prn2 | wc -l)
if [ "$TEST0" -ne "0" ]; then
  echo "Diff between prn output and tecplot output failed!" >&2
  echo "Exit code = 2"
  exit 2
else
  echo "Diff between prn output ($CIR2.prn2) and tecplot output ($CIR1.prn2) passed!"
  echo "test result = $TEST0"
fi

# grep for all the features that should be present in the tecplot header:
TEST1=$(grep -ic VARIABLES $CIR1.HOMOTOPY.dat)
TEST2=$(grep -ic GSTEPPING $CIR1.HOMOTOPY.dat)
TEST3=$(grep -ic TIME $CIR1.HOMOTOPY.dat)
TEST4=$(grep -ic VB $CIR1.HOMOTOPY.dat)
TEST5=$(grep -ic VIC $CIR1.HOMOTOPY.dat)
TEST6=$(grep -ic DATASETAUXDATA $CIR1.HOMOTOPY.dat)
TEST7=$(grep -ic ZONE $CIR1.HOMOTOPY.dat)
TEST8=$(grep -ic End $CIR1.HOMOTOPY.dat)

if [ "$TEST1" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of VARIABLES string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi

if [ "$TEST2" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of GSTEPPING string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi

if [ "$TEST3" -eq "2" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of TIME string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi
if [ "$TEST4" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of I(VB) string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi
if [ "$TEST5" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of I(VIC) string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi
if [ "$TEST6" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of DATASETAUXDATA string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi
if [ "$TEST7" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of ZONE string(s) in tecplot header" >&2
  echo "Exit code = 2"
  exit 2
fi
if [ "$TEST8" -eq "1" ]
then
  EXITCODE=0
else
  EXITCODE=2
  echo "Wrong number of End string(s) in tecplot footer" >&2
  echo "Exit code = 2"
  exit 2
fi

#if we have gotten here, nothing failed:
echo "Exit code = 0"
exit 0

